==> octave-3.2.2.tar.bz2: octave-3.2.2/scripts/image/jet.m <==
## Copyright (C) 1999, 2000, 2007, 2009 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.

## -*- texinfo -*-
## @deftypefn {Function File} {} jet (@var{n})
## Create color colormap.  This colormap is dark blue through blue, cyan, 
## green, yellow, red to dark red.  The argument @var{n} should be a scalar. 
## If it is omitted, the length of the current colormap or 64 is assumed.
## @seealso{colormap}
## @end deftypefn

## Author:  Kai Habel <kai.habel@gmx.de>

function map = jet (number)

  if (nargin == 0)
    number = rows (colormap);
  elseif (nargin == 1)
    if (! isscalar (number))
      error ("jet: argument must be a scalar");
    endif
  else
    print_usage ();
  endif

  if (number == 1)
    map = [0, 0, 0.5];  
  elseif (number > 1)
    x = linspace(0, 1, number)';
    r = (x >= 3/8 & x < 5/8) .* (4 * x - 3/2)\
      + (x >= 5/8 & x < 7/8) + (x >= 7/8) .* (-4 * x + 9/2);
    g = (x >= 1/8 & x < 3/8) .* (4 * x - 1/2)\
      + (x >= 3/8 & x < 5/8) + (x >= 5/8 & x < 7/8) .* (-4 * x + 7/2);
    b = (x < 1/8) .* (4 * x + 1/2) + (x >= 1/8 & x < 3/8)\
      + (x >= 3/8 & x < 5/8) .* (-4 * x + 5/2);
    map = [r, g, b];
  else
    map = [];
  endif

endfunction

==> octave_3.6.2.orig.tar.bz2: octave-3.6.2/scripts/image/jet.m <==
## Copyright (C) 1999-2012 Kai Habel
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.

## -*- texinfo -*-
## @deftypefn  {Function File} {@var{map} =} jet ()
## @deftypefnx {Function File} {@var{map} =} jet (@var{n})
## Create color colormap.  This colormap ranges from dark blue through blue,
## cyan, green, yellow, red, to dark red.
## The argument @var{n} must be a scalar.
## If unspecified, the length of the current colormap, or 64, is used.
## @seealso{colormap}
## @end deftypefn

## Author:  Kai Habel <kai.habel@gmx.de>

function map = jet (n)

  if (nargin == 0)
    n = rows (colormap);
  elseif (nargin == 1)
    if (! isscalar (n))
      error ("jet: argument must be a scalar");
    endif
  else
    print_usage ();
  endif

  if (n == 1)
    map = [0, 0, 0.5];
  elseif (n > 1)
    x = linspace(0, 1, n)';
    r = (x >= 3/8 & x < 5/8) .* (4 * x - 3/2)\
      + (x >= 5/8 & x < 7/8) + (x >= 7/8) .* (-4 * x + 9/2);
    g = (x >= 1/8 & x < 3/8) .* (4 * x - 1/2)\
      + (x >= 3/8 & x < 5/8) + (x >= 5/8 & x < 7/8) .* (-4 * x + 7/2);
    b = (x < 1/8) .* (4 * x + 1/2) + (x >= 1/8 & x < 3/8)\
      + (x >= 3/8 & x < 5/8) .* (-4 * x + 5/2);
    map = [r, g, b];
  else
    map = [];
  endif

endfunction

%!demo
%! ## Show the 'jet' colormap as an image
%! image (1:64, linspace (0, 1, 64), repmat (1:64, 64, 1)')
%! axis ([1, 64, 0, 1], "ticy", "xy")
%! colormap (jet (64))
